@@ -202,7 +202,7 @@ def add_self_loops(edge_index, edge_weight=None, fill_value=1, num_nodes=None):
 def normalize_adj_tensor(adj, sparse=False):
     """Normalize adjacency tensor matrix.
     """
-    device = torch.device("cuda" if adj.is_cuda else "cpu")
+    device = adj.device
     if sparse:
         # warnings.warn('If you find the training process is too slow, you can uncomment line 207 in deeprobust/graph/utils.py. Note that you need to install torch_sparse')
         # TODO if this is too slow, uncomment the following code,
@@ -258,7 +258,7 @@ def degree_normalize_adj_tensor(adj, sparse=True):
     """degree_normalize_adj_tensor.
     """
 
-    device = torch.device("cuda" if adj.is_cuda else "cpu")
+    device = adj.device
     if sparse:
         # return  degree_normalize_sparse_tensor(adj)
         adj = to_scipy(adj)
@@ -549,7 +549,7 @@ def get_degree_squence(adj):
     except:
         return ts.sum(adj, dim=1).to_dense()
 
-def likelihood_ratio_filter(node_pairs, modified_adjacency, original_adjacency, d_min, threshold=0.004):
+def likelihood_ratio_filter(node_pairs, modified_adjacency, original_adjacency, d_min, threshold=0.004, undirected=True):
     """
     Filter the input node pairs based on the likelihood ratio test proposed by Zügner et al. 2018, see
     https://dl.acm.org/citation.cfm?id=3220078. In essence, for each node pair return 1 if adding/removing the edge
@@ -595,7 +595,8 @@ def likelihood_ratio_filter(node_pairs, modified_adjacency, original_adjacency,
 
     allowed_mask = torch.zeros(modified_adjacency.shape)
     allowed_mask[filtered_edges.T] = 1
-    allowed_mask += allowed_mask.t()
+    if undirected:
+        allowed_mask += allowed_mask.t()
     return allowed_mask, current_ratio
 
 
